==> jena-5.3.0-source-release.zip: jena-5.3.0/jena-base/src/main/java/org/apache/jena/atlas/iterator/SingletonIterator.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.jena.atlas.iterator;

import java.util.Iterator ;
import java.util.NoSuchElementException ;

public class SingletonIterator<T> implements Iterator<T>
{
    private T thing = null ;
    private boolean yielded = false ;

    public SingletonIterator(T thing) { this.thing = thing ; }

    @Override
    public boolean hasNext()
    {
        return ! yielded ;
    }

    @Override
    public T next()
    {
        if ( yielded )
            throw new NoSuchElementException("SingletonIterator.next") ;
        yielded = true ;
        return thing ;
    }

    @Override
    public void remove()
    { throw new UnsupportedOperationException("SingletonIterator.remove") ;}
}

==> jena-5.6.0-source-release.zip: jena-5.6.0/jena-base/src/main/java/org/apache/jena/atlas/iterator/SingletonIterator.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.jena.atlas.iterator;

import java.util.Iterator ;
import java.util.NoSuchElementException ;

/**
 * Use {@link Iter#singletonIterator}.
 */
public class SingletonIterator<T> implements Iterator<T> {
    private T thing = null;
    private boolean yielded = false;

    public static <X> Iterator<X> create(X item){ return new SingletonIterator<>(item); }

    /*package*/ SingletonIterator(T thing) {
        this.thing = thing;
    }

    @Override
    public boolean hasNext() {
        return !yielded;
    }

    @Override
    public T next() {
        if ( yielded )
            throw new NoSuchElementException("SingletonIterator.next");
        yielded = true;
        return thing;
    }

    @Override
    public void remove() {
        throw new UnsupportedOperationException("SingletonIterator.remove");
    }
}
